==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Your_Account/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_YES","Ano");
define("_NO","Ne");
define("_OPTIONAL","(voliteln)");
define("_REQUIRED","(vyadovno)");
define("_SAVECHANGES","Uloit zmny");
define("_THRESHOLD","Prhy");
define("_NOCOMMENTS","Bez komente");
define("_NESTED","Vkldan");
define("_FLAT","Patra");
define("_THREAD","Strom");
define("_OLDEST","Nejdve star");
define("_NEWEST","Nejdve novj");
define("_HIGHEST","Nejdve s nejvym skre");
define("_ERRORINVEMAIL","CHYBA: Neplatn e-mail");
define("_ERROREMAILSPACES","CHYBA: E-mailov adresa nesm obsahovat mezery");
define("_ERRORINVNICK","CHYBA: Neplatn pezdvka");
define("_NICK2LONG","Pezdvka je pli dlouh. Nesm bt del ne 25 znak");
define("_NAMERESERVED","CHYBA: Toto jmno je ji zadan");
define("_NICKNOSPACES","CHYBA: Nemete pout mezery v pezdvce");
define("_NICKTAKEN","CHYBA: Tato pezdvka je ji zadan");
define("_EMAILREGISTERED","CHYBA: E-mailov adresa je ji registrovna");
define("_UUSERNAME","Uivatelsk jmno");
define("_FINISH","Konec");
define("_YOUUSEDEMAIL","Vy nebo nkdo jin pouil vai e-mailovou adresu");
define("_TOREGISTER","pro vytvoen tu na");
define("_FOLLOWINGMEM","Zde jsou registran informace:");
define("_UNICKNAME","-Pezdvka:");
define("_UPASSWORD","-Heslo:");
define("_USERPASS4","Uivatelsk heslo pro");
define("_YOUAREREGISTERED","Nyn mte zaloen et. Heslo obdrte na e-mailovou adresu, kterou jste zadal(a) pi registraci.");
define("_THISISYOURPAGE","Vae osobn strnka");
define("_AVATAR","Avatar-ikonka");
define("_WEBSITE","V web");
define("_ICQ","ICQ");
define("_AIM","AIM");
define("_YIM","YIM");
define("_MSNM","MSNM");
define("_LOCATION","Bydlit");
define("_OCCUPATION","Zamstnn");
define("_INTERESTS","Zjmy");
define("_SIGNATURE","Podpis");
define("_MYHOMEPAGE","Moje domovsk strnka:");
define("_MYEMAIL","Mj e-mail:");
define("_EXTRAINFO","Extra informace");
define("_NOINFOFOR","Nejsou dostupn informace o uivateli");
define("_LAST10COMMENTS","Poslednch 10 koment, kter poslal(a)");
define("_LAST10SUBMISSIONS","Poslednch 10 pspvk, kter poslal(a)");
define("_LOGININCOR","Chyba pi pihlovn! Zkuste to, prosm, znovu...");
define("_USERLOGIN","Pihlen");
define("_USERREGLOGIN","Nov registrace/Pihlen");
define("_REGNEWUSER","Registrace novho uivatele");
define("_LIST","Seznam");
define("_NEWUSER","Nov uivatel");
define("_PASSWILLSEND","((Heslo bude poslno na e-mailovou adresu, kterou jste zadal(a) pi registraci)");
define("_COOKIEWARNING","Poznmka: Pro uvn vhod registrace je teba mt povoleny cookies.");
define("_ASREGUSER","Jako registrovan uivatel mete:");
define("_ASREG1","Poslat koment s vaim jmnem(pezdvkou)");
define("_ASREG2","Poslat pspvek s vaim jmnem(pezdvkou)");
define("_ASREG3","Mt osobn box na vodn strnce");
define("_ASREG4","Zvolit kolik chcete mt zobrazeno pspvk na vodn strnce");
define("_ASREG5","Nastavit zobrazovn koment");
define("_ASREG6","Vybrat si jin design strnky");
define("_ASREG7","a spoustu dalch pknch malikost...");
define("_REGISTERNOW","Registrujte se ihned! Je to zdarma!");
define("_WEDONTGIVE","Vae osobn informace nebudou v dnm ppad pedny tetm osobm.");
define("_ALLOWEMAILVIEW","Povoluji zobrazen m e-mail adresy ostatnm uivatelm");
define("_OPTION","Volby");
define("_PASSWORDLOST","Zapoml(a) jste heslo?");
define("_NOPROBLEM","To nen dn problm. Zadejte vai pezdvku a kliknte na tlatko Poslat heslo. Na e-mailovou adresu, kterou jste zadal(a) pi registraci, vm okamit poleme potvrzovac kd. Znovu zadte vai pezdvku a potvrzovac kd a my vm ihned poleme nov heslo.");
define("_CONFIRMATIONCODE","Potvrzovac kd");
define("_SENDPASSWORD","Poslat heslo");
define("_YOUARELOGGEDOUT","Vae odhlen probhlo spn!");
define("_SORRYNOUSERINFO","Lituji, nebyly nalezeny odpovdajc informace");
define("_USERACCOUNT","Uivatelsk et");
define("_AT","na");
define("_HASTHISEMAIL","bylo spojeno s touto e-mailovou adresou.");
define("_AWEBUSERFROM","Uivatel");
define("_HASREQUESTED","podal(a) o posln heslat.");
define("_YOURNEWPASSWORD","Vae nov heslo je:");
define("_YOUCANCHANGE","Mete jej zmnit po pihlen na");
define("_IFYOUDIDNOTASK","Pokud jste o toto nepodal, nebute smutn. Vidte tuto zprvu, nikoli 'je'. Pokud se jedn o chybu, zalogujte se znovu - s novm heslem.");
define("_UPDATEFAILED","Nemohu aktualizovat uivatele. Kontaktujte, prosm administrtora.");
define("_PASSWORD4","Heslo pro");
define("_MAILED","Odeslno.");
define("_CODEREQUESTED","podal(a) o posln potvrzovacho kdu ke zmn hesla.");
define("_YOURCODEIS","V potvrzovac kd je:");
define("_WITHTHISCODE","S tmto kdem mete podat o pidlen novho hesla na");
define("_IFYOUDIDNOTASK2","Pokud jste o nic nedal(a), smate prosm tento e-mail.");
define("_CODEFOR","Potvrzovac kd pro");
define("_USERPASSWORD4","Uivatelsk heslo pro");
define("_UREALNAME","Prav jmno");
define("_UREALEMAIL","Prav e-mail");
define("_EMAILNOTPUBLIC","(Tato e-mailov adresa nebude zveejnna, je vak vyadovan. Pokud zapomenete(stratte) heslo, poleme vm na tuto adresu nov)");
define("_UFAKEMAIL","Falen e-mail");
define("_EMAILPUBLIC","(Tato adresa bude zveejnna. Prost zadejte co chcete.)");
define("_YOURHOMEPAGE","Vae domovsk strnka");
define("_YOURAVATAR","Vae Avatar-ikonka");
define("_YICQ","ICQ");
define("_YAIM","AIM");
define("_YYIM","YIM");
define("_YMSNM","MSNM");
define("_YLOCATION","Bydlit");
define("_YOCCUPATION","Zamstnn");
define("_YINTERESTS","Zjmy");
define("_255CHARMAX","(max. 255 znak. Zadejte v podpis, mete i s pouitm HTML)");
define("_CANKNOWABOUT","(max. 255 znak. Zadejte to, co chcete aby ostatn o vs vdli)");
define("_TYPENEWPASSWORD","(nov heslo zadejte dvakrt pro jeho zmnu)");
define("_SOMETHINGWRONG","Nco vs vyt... co vs roziluje?");
define("_PASSDIFFERENT","Zadan hesla jsou rozdln. Mus bt identick.");
define("_CHARLONG","znak");
define("_AVAILABLEAVATARS","Seznam dostupnch ikonek");
define("_NEWSINHOME","Poet pspvk na vodn strnce");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","Aktivovat osobn menu");
define("_CHECKTHISOPTION","(Zatrhnte tuto monost a na vodn strnce budete mt zobrazen box, ve kterm mete mt text nebo vlastn menu)");
define("_YOUCANUSEHTML","(Mete pout HTML kd)");
define("_SELECTTHEME","Vyberte jeden vzhled");
define("_THEMETEXT1","Tato volba zcela zmn vzhled celho webu.");
define("_THEMETEXT2","Zmny budou viditeln pouze pro vs.");
define("_THEMETEXT3","Vichni uivatel mohou mt nastaven rozdln vzhled webu.");
define("_DISPLAYMODE","Zobrazit jako");
define("_SORTORDER","Seadit");
define("_COMMENTSWILLIGNORED","Komente s nim hodnocenm ne nastavte budou ignorovny.");
define("_UNCUT","Nefiltrovat");
define("_EVERYTHING","Skoro vechno");
define("_FILTERMOSTANON","Filtrovat-vtinou anonymy");
define("_USCORE","Hodnocen");
define("_SCORENOTE","Anonymn pspvky zanaj na 0, pspvky pihlench uivatel na 1. Modertoi mohou pidvat a odebrat body.");
define("_NOSCORES","Nezobrazovat hodnocen");
define("_HIDDESCORES","(Skryt hodnocen: Pokud je zatrhnete, neuvidte dn hodnocen.)");
define("_MAXCOMMENT","Max dlka komente");
define("_TRUNCATES","(Zkrt dlouh komente a pid k nim odkaz: vce...)");
define("_BYTESNOTE","byt (1024 byt = 1K)");
define("_USENDPRIVATEMSG","Poslat osobn zprvu uivateli:");
define("_THEMESELECTION","Nastaven vzhledu");
define("_COMMENTSCONFIG","Nastaven koment");
define("_HOMECONFIG","Nastaven vodn strnky");
define("_PERSONALINFO","Osobn informace");
define("_USERSTATUS","Aktuln status");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","Osobn informace");
define("_CONFIGCOMMENTS","Nastaven koment");
define("_CHANGEHOME","Upravit v.strnku");
define("_LOGOUTEXIT","Odhlen/Konec");
define("_SELECTTHETHEME","Vybrat vzhled");
define("_PRIVATEMESSAGES","Vae osobn zprvy");
define("_EDITUSER","Upravit uivatele");
define("_RECEIVENEWSLETTER","Receive Newsletter by Email?");
define("_NOTSUBSCRIBED","You're not subscribed to our Newsletter");
define("_SUBSCRIBED","You're subscribed to our Newsletter");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Your_Account/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","E-mail");
define("_YES","Ano");
define("_NO","Ne");
define("_OPTIONAL","(voliteln)");
define("_REQUIRED","(vyadovno)");
define("_SAVECHANGES","Uloit zmny");
define("_THRESHOLD","Prhy");
define("_NOCOMMENTS","Bez komente");
define("_NESTED","Vkldan");
define("_FLAT","Patra");
define("_THREAD","Strom");
define("_OLDEST","Nejdve star");
define("_NEWEST","Nejdve novj");
define("_HIGHEST","Nejdve s nejvym skre");
define("_ERRORINVEMAIL","CHYBA: Neplatn e-mail");
define("_ERROREMAILSPACES","CHYBA: E-mailov adresa nesm obsahovat mezery");
define("_ERRORINVNICK","CHYBA: Neplatn pezdvka");
define("_NICK2LONG","Pezdvka je pli dlouh. Nesm bt del ne 25 znak");
define("_NAMERESERVED","CHYBA: Toto jmno je ji zadan");
define("_NICKNOSPACES","CHYBA: Nemete pout mezery v pezdvce");
define("_NICKTAKEN","CHYBA: Tato pezdvka je ji zadan");
define("_EMAILREGISTERED","CHYBA: E-mailov adresa je ji registrovna");
define("_UUSERNAME","Uivatelsk jmno");
define("_FINISH","Konec");
define("_YOUUSEDEMAIL","Vy nebo nkdo jin pouil vai e-mailovou adresu");
define("_TOREGISTER","pro vytvoen tu na");
define("_FOLLOWINGMEM","Zde jsou registran informace:");
define("_UNICKNAME","-Pezdvka:");
define("_UPASSWORD","-Heslo:");
define("_USERPASS4","Uivatelsk heslo pro");
define("_YOUAREREGISTERED","Nyn mte zaloen et. Heslo obdrte na e-mailovou adresu, kterou jste zadal(a) pi registraci.");
define("_THISISYOURPAGE","Vae osobn strnka");
define("_AVATAR","Avatar-ikonka");
define("_WEBSITE","V web");
define("_ICQ","ICQ");
define("_AIM","AIM");
define("_YIM","YIM");
define("_MSNM","MSNM");
define("_LOCATION","Bydlit");
define("_OCCUPATION","Zamstnn");
define("_INTERESTS","Zjmy");
define("_SIGNATURE","Podpis");
define("_MYHOMEPAGE","Moje domovsk strnka:");
define("_MYEMAIL","Mj e-mail:");
define("_EXTRAINFO","Extra informace");
define("_NOINFOFOR","Nejsou dostupn informace o uivateli");
define("_LAST10COMMENTS","Poslednch 10 koment, kter poslal(a)");
define("_LAST10SUBMISSIONS","Poslednch 10 pspvk, kter poslal(a)");
define("_LOGININCOR","Chyba pi pihlovn! Zkuste to, prosm, znovu...");
define("_USERLOGIN","Pihlen");
define("_USERREGLOGIN","Nov registrace/Pihlen");
define("_REGNEWUSER","Registrace novho uivatele");
define("_LIST","Seznam");
define("_NEWUSER","Nov uivatel");
define("_PASSWILLSEND","((Heslo bude poslno na e-mailovou adresu, kterou jste zadal(a) pi registraci)");
define("_COOKIEWARNING","Poznmka: Pro uvn vhod registrace je teba mt povoleny cookies.");
define("_ASREGUSER","Jako registrovan uivatel mete:");
define("_ASREG1","Poslat koment s vaim jmnem(pezdvkou)");
define("_ASREG2","Poslat pspvek s vaim jmnem(pezdvkou)");
define("_ASREG3","Mt osobn box na vodn strnce");
define("_ASREG4","Zvolit kolik chcete mt zobrazeno pspvk na vodn strnce");
define("_ASREG5","Nastavit zobrazovn koment");
define("_ASREG6","Vybrat si jin design strnky");
define("_ASREG7","a spoustu dalch pknch malikost...");
define("_REGISTERNOW","Registrujte se ihned! Je to zdarma!");
define("_WEDONTGIVE","Vae osobn informace nebudou v dnm ppad pedny tetm osobm.");
define("_ALLOWEMAILVIEW","Povoluji zobrazen m e-mail adresy ostatnm uivatelm");
define("_OPTION","Volby");
define("_PASSWORDLOST","Zapoml(a) jste heslo?");
define("_NOPROBLEM","To nen dn problm. Zadejte vai pezdvku a kliknte na tlatko Poslat heslo. Na e-mailovou adresu, kterou jste zadal(a) pi registraci, vm okamit poleme potvrzovac kd. Znovu zadte vai pezdvku a potvrzovac kd a my vm ihned poleme nov heslo.");
define("_CONFIRMATIONCODE","Potvrzovac kd");
define("_SENDPASSWORD","Poslat heslo");
define("_YOUARELOGGEDOUT","Vae odhlen probhlo spn!");
define("_SORRYNOUSERINFO","Lituji, nebyly nalezeny odpovdajc informace");
define("_USERACCOUNT","Uivatelsk et");
define("_AT","na");
define("_HASTHISEMAIL","bylo spojeno s touto e-mailovou adresou.");
define("_AWEBUSERFROM","Uivatel");
define("_HASREQUESTED","podal(a) o posln heslat.");
define("_YOURNEWPASSWORD","Vae nov heslo je:");
define("_YOUCANCHANGE","Mete jej zmnit po pihlen na");
define("_IFYOUDIDNOTASK","Pokud jste o toto nepodal, nebute smutn. Vidte tuto zprvu, nikoli 'je'. Pokud se jedn o chybu, zalogujte se znovu - s novm heslem.");
define("_UPDATEFAILED","Nemohu aktualizovat uivatele. Kontaktujte, prosm administrtora.");
define("_PASSWORD4","Heslo pro");
define("_MAILED","Odeslno.");
define("_CODEREQUESTED","podal(a) o posln potvrzovacho kdu ke zmn hesla.");
define("_YOURCODEIS","V potvrzovac kd je:");
define("_WITHTHISCODE","S tmto kdem mete podat o pidlen novho hesla na");
define("_IFYOUDIDNOTASK2","Pokud jste o nic nedal(a), smate prosm tento e-mail.");
define("_CODEFOR","Potvrzovac kd pro");
define("_USERPASSWORD4","Uivatelsk heslo pro");
define("_UREALNAME","Prav jmno");
define("_UREALEMAIL","Prav e-mail");
define("_EMAILNOTPUBLIC","(Tato e-mailov adresa nebude zveejnna, je vak vyadovan. Pokud zapomenete(stratte) heslo, poleme vm na tuto adresu nov)");
define("_UFAKEMAIL","Falen e-mail");
define("_EMAILPUBLIC","(Tato adresa bude zveejnna. Prost zadejte co chcete.)");
define("_YOURHOMEPAGE","Vae domovsk strnka");
define("_YOURAVATAR","Vae Avatar-ikonka");
define("_YICQ","ICQ");
define("_YAIM","AIM");
define("_YYIM","YIM");
define("_YMSNM","MSNM");
define("_YLOCATION","Bydlit");
define("_YOCCUPATION","Zamstnn");
define("_YINTERESTS","Zjmy");
define("_255CHARMAX","(max. 255 znak. Zadejte v podpis, mete i s pouitm HTML)");
define("_CANKNOWABOUT","(max. 255 znak. Zadejte to, co chcete aby ostatn o vs vdli)");
define("_TYPENEWPASSWORD","(nov heslo zadejte dvakrt pro jeho zmnu)");
define("_SOMETHINGWRONG","Nco vs vyt... co vs roziluje?");
define("_PASSDIFFERENT","Zadan hesla jsou rozdln. Mus bt identick.");
define("_CHARLONG","znak");
define("_AVAILABLEAVATARS","Seznam dostupnch ikonek");
define("_NEWSINHOME","Poet pspvk na vodn strnce");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","Aktivovat osobn menu");
define("_CHECKTHISOPTION","(Zatrhnte tuto monost a na vodn strnce budete mt zobrazen box, ve kterm mete mt text nebo vlastn menu)");
define("_YOUCANUSEHTML","(Mete pout HTML kd)");
define("_SELECTTHEME","Vyberte jeden vzhled");
define("_THEMETEXT1","Tato volba zcela zmn vzhled celho webu.");
define("_THEMETEXT2","Zmny budou viditeln pouze pro vs.");
define("_THEMETEXT3","Vichni uivatel mohou mt nastaven rozdln vzhled webu.");
define("_DISPLAYMODE","Zobrazit jako");
define("_SORTORDER","Seadit");
define("_COMMENTSWILLIGNORED","Komente s nim hodnocenm ne nastavte budou ignorovny.");
define("_UNCUT","Nefiltrovat");
define("_EVERYTHING","Skoro vechno");
define("_FILTERMOSTANON","Filtrovat-vtinou anonymy");
define("_USCORE","Hodnocen");
define("_SCORENOTE","Anonymn pspvky zanaj na 0, pspvky pihlench uivatel na 1. Modertoi mohou pidvat a odebrat body.");
define("_NOSCORES","Nezobrazovat hodnocen");
define("_HIDDESCORES","(Skryt hodnocen: Pokud je zatrhnete, neuvidte dn hodnocen.)");
define("_MAXCOMMENT","Max dlka komente");
define("_TRUNCATES","(Zkrt dlouh komente a pid k nim odkaz: vce...)");
define("_BYTESNOTE","byt (1024 byt = 1K)");
define("_USENDPRIVATEMSG","Poslat osobn zprvu uivateli:");
define("_THEMESELECTION","Nastaven vzhledu");
define("_COMMENTSCONFIG","Nastaven koment");
define("_HOMECONFIG","Nastaven vodn strnky");
define("_PERSONALINFO","Osobn informace");
define("_USERSTATUS","Aktuln status");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","Osobn informace");
define("_CONFIGCOMMENTS","Nastaven koment");
define("_CHANGEHOME","Upravit v.strnku");
define("_LOGOUTEXIT","Odhlen/Konec");
define("_SELECTTHETHEME","Vybrat vzhled");
define("_PRIVATEMESSAGES","Vae osobn zprvy");
define("_EDITUSER","Upravit uivatele");
define("_RECEIVENEWSLETTER","Receive Newsletter by Email?");
define("_NOTSUBSCRIBED","You're not subscribed to our Newsletter");
define("_SUBSCRIBED","You're subscribed to our Newsletter");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>
